Skip to contents

Function creates Shiny app project directory structured as an R package.

Usage

new_dph_shiny_app(path, ...)

Arguments

path

The path where to create the project is supplied by the RStudio interface.

...

Passes other parameters from the RStudio new project wizard