Function creates Shiny app project directory structured as an R package.
new_dph_shiny_app.RdFunction creates Shiny app project directory structured as an R package.
new_dph_shiny_app.RdFunction creates Shiny app project directory structured as an R package.